@@ -43,7 +43,7 @@ class Repo:
             self._sample_programs_website_repo: git.Repo = git.Repo.clone_from("https://github.com/TheRenegadeCoder/sample-programs-website.git", self._sample_programs_website_repo_dir)
         
         # Sets up paths to relevant directories
-        self._docs_dir: str = os.path.join(self._sample_programs_website_repo_dir, "docs")
+        self._docs_source_dir: str = os.path.join(self._sample_programs_website_repo_dir, "sources")
         self._archive_dir: str = os.path.join(self._sample_programs_repo_dir, "archive")
         
         # Performs data collection from the repos
@@ -52,7 +52,10 @@ class Repo:
         self._languages: Dict[str: LanguageCollection] = self._collect_languages()
         self._total_snippets: int = sum(x.total_programs() for _, x in self._languages.items())
         self._total_tests: int = sum(1 for _, x in self._languages.items() if x.has_testinfo())
+        
+        # Post generation updates
         self._load_git_data()
+        self._load_docs_data()
         
         # Closes repositories
         self._sample_programs_repo.close()
@@ -220,9 +223,9 @@ class Repo:
 
         :return: a list of string objects representing the projects
         """
-        logger.info(f"Collecting projects along path: {self._docs_dir}")
+        logger.info(f"Collecting projects along path: {self._docs_source_dir}")
         projects = []
-        for project_dir in Path(self._docs_dir, "projects").iterdir():
+        for project_dir in Path(self._docs_source_dir, "projects").iterdir():
             if project_dir.is_dir():
                 project_test = self._tested_projects.get("".join(project_dir.name.split("-")))
                 logger.info(f"Generating project from: {project_dir.name}, {project_test}")
@@ -273,6 +276,48 @@ class Repo:
         # Delete .git-blame-ignore-revs if it did not exist before
         if not blame_path_exists:
             blame_path.unlink()
+            
+            
+    def _load_docs_data(self) -> None:
+        """
+        Once the repo is loaded, this method will load the documentation data from
+        the website repo and inject that data into the repo object.
+        """
+        
+        # Loads project docs
+        for project in self._projects:
+            project: Project
+            project_docs_path = Path(self._docs_source_dir, "projects", project.pathlike_name())
+            if project_docs_path.exists():
+                logger.info(f"Project has documentation at {project_docs_path}")
+                project._docs_path = project_docs_path
+                project._docs_files = []
+                for file in project_docs_path.glob("*"):
+                    project._docs_files.append(file.name)
+                
+        # Loads language docs
+        for language in self:
+            language: LanguageCollection
+            language_docs_path = Path(self._docs_source_dir, "languages", language.pathlike_name())
+            if language_docs_path.exists():
+                language._docs_path = language_docs_path
+                language._docs_files = []
+                for file in language_docs_path.glob("*"):
+                    language._docs_files.append(file.name)
+                    
+        # Loads sample programs docs
+        for language in self:
+            language: LanguageCollection
+            for program in language:
+                program: SampleProgram
+                program_docs_path = Path(self._docs_source_dir, "programs", program.project_pathlike_name(), program.language_pathlike_name())
+                if program_docs_path.exists():
+                    logger.info(f"Program has documentation at {program_docs_path}")
+                    program._docs_path = program_docs_path
+                    program._docs_files = []
+                    for file in program_docs_path.glob("*"):
+                        program._docs_files.append(file.name)
+        
 
 class LanguageCollection:
     """
@@ -293,6 +338,8 @@ class LanguageCollection:
         self._path: str = path
         self._file_list: List[str] = file_list
         self._projects: List[Project] = projects
+        self._docs_path: str = None
+        self._docs_files: list[str] = None
         self._first_letter: str = name[0]
         self._sample_programs: Dict[str, SampleProgram] = self._collect_sample_programs()
         self._test_file_path: Optional[str] = self._collect_test_file()
@@ -488,6 +535,20 @@ class LanguageCollection:
         logger.info(
             f"Retrieving total line count for {self}: {self._total_line_count}")
         return self._total_line_count
+    
+    def has_docs(self) -> bool:
+        """
+        Retrieves the documentation state of this language. Note that documentation
+        may not be complete or up to date. 
+        
+        Assuming you have a LanguageCollection object called language, 
+        here's how you would use this method::
+
+            state: bool = language.has_docs() 
+
+        :return: returns true if the language has a documentation folder created for it; false otherwise
+        """
+        return bool(self._docs_path)
 
     def lang_docs_url(self) -> str:
         """
@@ -632,6 +693,8 @@ class SampleProgram:
         self._authors: set = set()
         self._created: Optional[datetime.datetime] = None
         self._modified: Optional[datetime.datetime] = None
+        self._docs_path: str = None
+        self._docs_files: list[str] = None
 
     def __str__(self) -> str:
         """
@@ -845,6 +908,20 @@ class SampleProgram:
         """
         logger.info(f'Retrieving line count for {self}: {self._line_count}')
         return self._line_count
+    
+    def has_docs(self) -> bool:
+        """
+        Retrieves the documentation state of this program. Note that documentation
+        may not be complete or up to date. 
+        
+        Assuming you have a SampleProgram object called program, 
+        here's how you would use this method::
+
+            state: bool = program.has_docs() 
+
+        :return: returns true if the program has a documentation folder created for it; false otherwise
+        """
+        return bool(self._docs_path)
 
     def documentation_url(self) -> str:
         """
@@ -944,12 +1021,15 @@ class Project:
     An object representing a Project in the Sample Programs repo.
 
     :param str name: the name of the project in its pathlike form (e.g., hello-world) 
+    :param project_tests: a dictionary containing the test rules for the project
     """
 
     def __init__(self, name: str, project_tests: Optional[Dict]):
         self._project_tests = project_tests
         self._name: str = Project._generate_name(name)
         self._requirements_url: str = self._generate_requirements_url()
+        self._docs_path: str = None
+        self._docs_files: list[str] = None
 
     def __str__(self) -> str:
         logger.info(f"Generating name from {self._name}")
